Crate bitcoin_address_book

Crate bitcoin_address_book 

This crate assists in managing network addresses gossiped over the Bitcoin peer-to-peer network. The goals of an address book are to prevent any single peer from filling all entries in the address book, resist eclipse attacks, and to help find useful peers quickly.

Modules

io
Perform basic I/O operations on the address book.

Structs

Record
A record of a potential Bitcoin peer.
Table
A table of records to store potential peers. Some properties of this table are: a single source of gossip cannot fill this entire table with addresses, the table is a fixed size and held entirely in memory, the table is represented as a 2D matrix.